//
//  ADVChunkProcessor.h
//
//  Object for processing chunks of a web page. Each processor returns the text
//  between the start and end tags. Additional processing can be done by calling
//  the utility selectors.
//
//  Created by Michael Dupuis
//  Copyright (c) 2006-2008 Advenio, LLC. All rights reserved.
//

/*
 IMPORTANT:  This Advenio software is supplied to you by Advenio, LLC. ("Advenio") in
 consideration of your agreement to the following terms, and your use, installation, 
 modification or redistribution of this Advenio software constitutes acceptance of these 
 terms.  If you do not agree with these terms, please do not use, install, modify or 
 redistribute this Advenio software.
 
 In consideration of your agreement to abide by the following terms, and subject to these 
 terms, Advenio grants you a personal, non-exclusive license, under Advenio's copyrights in 
 this original Advenio software (the "Advenio Software"), to use, reproduce, modify and 
 redistribute the Advenio Software, with or without modifications, in source and/or binary 
 forms; provided that if you redistribute the Advenio Software in its entirety and without 
 modifications, you must retain this notice and the following text and disclaimers in all 
 such redistributions of the Advenio Software.  Neither the name, trademarks, service marks 
 or logos of Advenio, LLC. may be used to endorse or promote products derived from 
 the Advenio Software without specific prior written permission from Advenio. Except as expressly
 stated in this notice, no other rights or licenses, express or implied, are granted by Advenio
 herein, including but not limited to any patent rights that may be infringed by your 
 derivative works or by other works in which the Advenio Software may be incorporated.

 Additionally, the Advenio Software shall not be used to enhance, or be incorporated into,
 any other application that processes, stores or manipulates recipes. By using this Advenio
 Softare you agree to only use it to enhance MacGourmet, or it's related components.
 
 The Advenio Software is provided by Advenio on an "AS IS" basis.  ADVENIO MAKES NO WARRANTIES, 
 EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, 
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE ADVENIO SOFTWARE OR ITS 
 USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
 
 IN NO EVENT SHALL ADVENIO BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL 
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, 
 REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE ADVENIO SOFTWARE, HOWEVER CAUSED AND 
 WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR 
 OTHERWISE, EVEN IF ADVENIO HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>

// Identifier tags for the type of chunk being processed

#define TITLE		0
#define INGREDIENTS 1
#define DIRECTIONS	2
#define IMAGE		3
#define SUMMARY		4
#define PREP_TIMES	5
#define SERVINGS	6
#define SOURCE		7
#define YIELD		8
#define NOTES		9
#define DIFFICULTY	10
#define RATING		11
#define NUTRITION	12

@interface ADVChunkProcessor : NSObject
{
	@private
	
	int _type;
	id _value;
	NSString *_startTag;
	NSString *_endTag;
	ADVChunkProcessor *_nextProcessor;
}

/**
 * Init the processor.
 * type: The type of processor
 * start: The beginning tag
 * end: The ending tag
 */
- (id)initWithType:(int)type startTag:(NSString *)start endTag:(NSString *)end;

/** */
- (int)type;
- (void)setType:(int)type;

/** Returns the current processed value for this processor. */
- (id)value;
- (void)setValue:(id)value;

/** */
- (NSString *)startTag;
- (void)setStartTag:(NSString *)start;

/** */
- (NSString *)endTag;
- (void)setEndTag:(NSString *)end;

/** */
- (void)setNextProcessor:(ADVChunkProcessor *)nextProcessor;
- (ADVChunkProcessor *)nextProcessor;

/** Process the specified string, using the tags defined by start and end. */
- (BOOL)processString:(NSString *)string;

////////////////
// Utilities
////////////////

/** Strip <BR> tags from the string passed in. If replaceWithNewLines is YES, replace them with '\n' newlines. */
- (void)stripBRTagsFromString:(NSMutableString *)string replacingWithNewLines:(BOOL)replaceWithNewLines;

/** Strip the specified tags from the string passed in, replacing them with the string specified in replacement. */
- (void)stripTags:(NSString *)tag fromString:(NSMutableString *)string replacingWithString:(NSString *)replacement;

/**
 * Strip the common HTML tags from the string. Tags included are <p>, <div>,
 * <li>, <ul>, <ol>, <td>, <b>, and <i>.
 */
- (void)stripCommonTags;

/** Strip all of the <br> tags in the current processor string, replacing them with newlines if replaceWithNewLines is YES. */
- (void)stripBRTagsReplacingWithNewLines:(BOOL)replaceWithNewLines;

/** Replace HTML encodings commonly found with their UTF8 equivalents. */
- (void)replaceCommonHTMLEncodings;

/**
 * Replace encodings, basically all of the encodings for many foreign characters, represented by
 * textual symbols, rather than numberic ones.
 * http://www.everything2.com/index.pl?node=Latin-1%20Supplement
 */
- (void)replaceTextualHTMLEncodings;

/**
 * Strip all of the links from the current processor text (from any <a href=""> to a </a>.
 */
- (void)stripLinkKeepingText:(BOOL)keepText;

@end
