//
//  ADVWebSitePlugin.h
//
//  Base class for web site importer plug-ins.
//
//  Copyright (c) 2007 Advenio. All rights reserved.
//

/*
 IMPORTANT:  This Advenio software is supplied to you by Advenio, LLC. ("Advenio") in
 consideration of your agreement to the following terms, and your use, installation, 
 modification or redistribution of this Advenio software constitutes acceptance of these 
 terms.  If you do not agree with these terms, please do not use, install, modify or 
 redistribute this Advenio software.
 
 In consideration of your agreement to abide by the following terms, and subject to these 
 terms, Advenio grants you a personal, non-exclusive license, under Advenio's copyrights in 
 this original Advenio software (the "Advenio Software"), to use, reproduce, modify and 
 redistribute the Advenio Software, with or without modifications, in source and/or binary 
 forms; provided that if you redistribute the Advenio Software in its entirety and without 
 modifications, you must retain this notice and the following text and disclaimers in all 
 such redistributions of the Advenio Software.  Neither the name, trademarks, service marks 
 or logos of Advenio, LLC. may be used to endorse or promote products derived from 
 the Advenio Software without specific prior written permission from Advenio. Except as expressly
 stated in this notice, no other rights or licenses, express or implied, are granted by Advenio
 herein, including but not limited to any patent rights that may be infringed by your 
 derivative works or by other works in which the Advenio Software may be incorporated.

 Additionally, the Advenio Software shall not be used to enhance, or be incorporated into,
 any other application that processes, stores or manipulates recipes. By using this Advenio
 Softare you agree to only use it to enhance MacGourmet, or it's related components.
 
 The Advenio Software is provided by Advenio on an "AS IS" basis.  ADVENIO MAKES NO WARRANTIES, 
 EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, 
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE ADVENIO SOFTWARE OR ITS 
 USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
 
 IN NO EVENT SHALL ADVENIO BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL 
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, 
 REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE ADVENIO SOFTWARE, HOWEVER CAUSED AND 
 WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR 
 OTHERWISE, EVEN IF ADVENIO HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>
#import "ADVImportExportPlugin.h"

#define WEB_NAME		@"NAME"
#define WEB_SUMMARY		@"SUMMARY"
#define WEB_INGREDIENTS @"INGREDIENTS"
#define WEB_METHOD		@"METHOD"
#define WEB_SERVINGS	@"SERVINGS"
#define WEB_YIELD		@"YIELD"
#define WEB_NOTES		@"NOTES"
#define WEB_IMAGE		@"IMAGE"
#define WEB_PREP_TIMES	@"PREP_TIMES"
#define WEB_PREP		@"PREP"
#define WEB_NUTRITION	@"NUTRITION"
#define WEB_SOURCE		@"SOURCE"
#define WEB_SOURCE_INFO	@"PUBLICATION_PAGE"

@interface ADVWebSitePlugin : ADVImportExportPlugin
{
	NSImage *faviconImage;
	NSMutableData *_faviconReceivedData;
	NSURLConnection *connection;
}

/** Returns a dictionary filled in with the following values from the webpage at
 * the specified URL:
 *
 * NAME			NSString
 * SUMMARY		NSString
 * INGREDIENTS	NSString (Unparsed, ingredients separated by newlines)
 * METHOD		NSString
 * SERVINGS		NSString (int value)
 * YIELD		NSString
 * NOTES		NSString
 * IMAGE		NSImage object
 * PREP_TIMES	NSArray of Dictionaries {TYPE: HOURS: MINUTES:}
 * PREP_TIME	NSString string version of prep if it can't be parsed well
 * NUTRITION	NSString
 * SOURCE		NSString
 * PUBLICATION_PAGE	NSString (usually a web page URL)
 */
- (NSDictionary *)importSiteWithURL:(NSString *)siteURL;

/** Returns YES if the plugin can import the site with the specifed URL, NO if it cannot. */
- (BOOL)canImportSiteWithURL:(NSString *)siteURL;

/** Internal utility method. */
- (NSData *)dataFromNSURLConnectionWithURL:(NSURL *)theURL;

- (NSDictionary *)prepTimeWithType:(NSString *)type value:(NSString *)value;

/** Returns the URL to the favicon icon */
- (NSURL *)faviconURL;

/** Returns the favicon for the web site. Subclasses should implement. */
- (NSImage *)favicon;

@end